#
# spec file for package dsda-doom
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dsda-doom
Version:        0.29.0
Release:        1.1
Summary:        DOOM source port with Hexen support and demo compatibility
License:        GPL-2.0-or-later
Group:          Amusements/Games/3D/Shoot
URL:            https://github.com/kraflab/dsda-doom

#Changelog:     https://github.com/kraflab/dsda-doom/tree/master/patch_notes
#Announce:      https://www.doomworld.com/forum/topic/118074-dsda-doom-source-port-v0243/
Source:         https://github.com/kraflab/dsda-doom/archive/refs/tags/v%version.tar.gz
Patch1:         prboom-hbar-all.diff
Patch2:         prboom-hbar-gradient.diff
BuildRequires:  Mesa-devel
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  fluidsynth
BuildRequires:  hicolor-icon-theme
BuildRequires:  libpng-devel
BuildRequires:  libzip-tools
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_net)
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(mad)
BuildRequires:  pkgconfig(portmidi)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vorbis)
%if 0%{?suse_version} >= 1600
# CMake Error at [portmidi-devel]:/usr/lib64/cmake/PortMidi/PortMidiTargets.cmake:100 (message):
#   The imported target "PortMidi::pmjni" references the file
#      "[portmidi-java]:/usr/lib64/libpmjni.so.2.0.3"
BuildRequires:  portmidi-java
%endif
Suggests:       freedoom
Provides:       prboom

%description
DSDA-Doom is a source port derived from the PrBoom history line.
It features:

* Extra tooling for demo recording, with focus on speedrunning:
  record-rewind support
* Heretic and Hexen support
* MBFv21, UMAPINFO and DSDHacked specification support

%prep
%autosetup -p1

%build
cd prboom2/
%cmake -DDOOMWADDIR="%_datadir/doom" -DDSDAPWADDIR="%_datadir/doom" -D_IMPORT_PREFIX=$PWD/usr
%cmake_build

%install
cd prboom2/
%cmake_install
rm -f "%buildroot/usr/share/doc/dsda-doom/COPYING" # via %%license instead

%if 0%{?suse_version} && 0%{?suse_version} < 1550
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%_bindir/*
%_datadir/doom/
%_datadir/applications/*.desktop
%_datadir/icons/hicolor/
%doc docs/*.md
%license prboom2/COPYING

%changelog
* Thu Apr 10 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.29
  * Reorganized all menus
  * Strict mode is now On by default when recording demos
  * Don't allow saving the game on strict mode
  * Added support for reading GAMEINFO lump ("iwad" field only)
  * Added config option for toggling aspect ratio correction
  * Added linear sky scrolling option for Software renderer
  * Added smooth chainsaw bobbing (only when Uncapped FPS is on)
  * Remove SysEx support from FluidSynth midi player
  * automap: New colors for "Alt Secret Exit line" and
    "Tag Finder line"
  * Checks if a map exists before changing music with IDMUS
  * New cheat SKILL
* Thu Mar 20 2025 Jan Engelhardt <jengelh@inai.de>
- Remove unused BuildRequire on libpcre. (The feature using pcre
  was dropped in 2022 already.)
- Add BuildRequire on pkgconfig(glu), previously implicitly added
  by SDL2-devel (but now we have sdl2-compat-devel).
- Make build recipe POSIX sh compatible.
* Fri Jan 17 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.28.3
  * Added -track_reality command-line option
  * Added "Auto Switch Weapon on Pickup" option
  * Added shaded overlay for the automap and options menu
  * Added horizontal mouse wheel support
  * Added low-res aspect ratio correction on OpenGL to match
    software rendering
  * Improved software fuzz to not scale with the resolution
  * Improved automap zoom / scroll speeds
* Sat Oct 26 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.28.2
  * Added ANIMATED support to Heretic
  * Fixed mbf21 add / remove NOBLOCKMAP or NOSECTOR dehacked
    crashes
* Sun Aug 18 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.28.1
  * Fixed freelook menu crash, fixed numlock menu crash
* Thu Aug 15 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to release 0.28.0
  * Freelook aiming and projectile behavior has been rewritten
  * Added MAPINFO flags to support finite height explosion behavior
  * Added MAPINFO flags to support freelook
  * improvement on Tools, Console, and many Bug Fixes
    see https://github.com/kraflab/dsda-doom/blob/master/patch_notes/v0.28.md
- Delete cmake-path-suffix.diff
* Sun Dec  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.27.5
  * DSDAHUD lumps are "merged" now so only redefined huds are changed
  * Fixed umapinfo bunny scroller crash
* Sat Nov 18 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.27.4
  * Added option to hide stat labels and totals
  * Fixed an overflow causing distant sprites (~8k map units) to
    not be rendered
* Sun Nov  5 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.27.3
  * New indexed light mode (software fidelity in OpenGL).
  * Improved controller support.
  * A new HUD system with new components.
  * New console commands and better usability.
  * UDMF support, MAPINFO support
  * ZIP file loading
  * Improved Heretic and Hexen suport
  * Upgraded to OPL3 emulation
  * You can switch back to OPL2 with config option mus_opl_opl3mode
- Delete prboom-nodatetime.diff, fluidsynth1.diff
- Add cmake-path-suffix.diff
- Note: If you updated from an old dsda-doom and use the same
  config file, your default complevel may have been reset to 0. If
  you run into an issue, check it out (suggested value is 21 /
  mbf21, if you don't know what to pick).
* Wed Mar 30 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.24.3
  * Improved automatic keyframe timeout behaviour
  * Fixed a crash caused by saving the game state after an
    intercept overrun
  * Added mouse stutter correction option (on by default)
- Add fluidsynth1.diff
* Fri Mar  4 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.24.2
  * Added another batch of cheats to the console
  * Removed process affinity hack
  * Added support for SNDFONT lump
  * Moved default soundfont into dsda-doom.wad
* Sat Feb 19 2022 Jan Engelhardt <jengelh@inai.de>
- Initial package (v0.24.1) for build.opensuse.org
- Reuse prboom-hbar-all.diff, prboom-hbar-gradient.diff,
  prboom-nodatetime.diff from prboom-plus package.
